.. _api:

API Documentation
=================

This section contains the API documentation for all the functions in the module. Each function is documented on a separate page.

.. toctree::
   :maxdepth: 1
   :caption: Function Reference

   splitCountsColwise
   generate_cf_finite_optimized
   generate_cf_asymp_optimized
   compute_pvalue
   compute_test_stat
   effectSize_bin
   OASIS_pvalue
